import * as React from "react";

function ContactForm() {
  return (
    <div className="flex flex-col ml-5 w-6/12 max-md:ml-0 max-md:w-full">
      <form className="flex overflow-hidden flex-col grow w-full rounded-2xl bg-white bg-opacity-0 shadow-[0px_1px_0px_rgba(0,0,0,0.04)] max-md:mt-10 max-md:max-w-full">
        <div className="flex flex-col px-9 py-14 w-full bg-sky-50 max-md:px-5 max-md:max-w-full">
          <div className="self-start text-2xl font-semibold leading-loose text-blue-950">
            Send us a Message
          </div>
          
          <label htmlFor="inquiryType" className="sr-only">Inquiry Type</label>
          <select 
            id="inquiryType"
            className="p-3.5 mt-7 text-sm leading-none bg-white rounded-xl border border-solid border-neutral-200 text-neutral-600 max-md:pr-5 max-md:max-w-full"
          >
            <option>Inquiry Type</option>
          </select>

          <div className="flex flex-wrap gap-3 mt-4 text-xs text-blue-950 max-md:max-w-full">
            <div className="flex-1">
              <label htmlFor="firstName" className="sr-only">First Name</label>
              <input
                id="firstName"
                type="text"
                placeholder="First Name"
                className="w-full px-2.5 py-4 bg-white rounded-xl border border-solid border-neutral-200"
              />
            </div>
            <div className="flex-1">
              <label htmlFor="lastName" className="sr-only">Last Name</label>
              <input
                id="lastName"
                type="text"
                placeholder="Last Name"
                className="w-full px-2.5 py-4 bg-white rounded-xl border border-solid border-neutral-200"
              />
            </div>
          </div>

          <div className="flex flex-wrap gap-3 mt-4 text-xs text-blue-950 max-md:max-w-full">
            <div className="flex-1">
              <label htmlFor="companyName" className="sr-only">Company Name</label>
              <input
                id="companyName"
                type="text"
                placeholder="Company Name"
                className="w-full px-2.5 py-4 bg-white rounded-xl border border-solid border-neutral-200"
              />
            </div>
            <div className="flex-1">
              <label htmlFor="phone" className="sr-only">Phone</label>
              <input
                id="phone"
                type="tel"
                placeholder="Phone"
                className="w-full px-2.5 py-4 bg-white rounded-xl border border-solid border-neutral-200"
              />
            </div>
          </div>

          <div className="mt-4">
            <label htmlFor="email" className="sr-only">Email Address</label>
            <input
              id="email"
              type="email"
              placeholder="Email Address"
              className="w-full px-2.5 py-4 bg-white rounded-xl border border-solid border-neutral-200 text-xs text-blue-950"
            />
          </div>

          <div className="mt-4">
            <label htmlFor="message" className="sr-only">How can we help?</label>
            <textarea
              id="message"
              placeholder="How can we help?"
              className="w-full px-2.5 pt-4 pb-16 bg-white rounded-xl border border-solid border-neutral-200 text-xs leading-loose text-blue-950"
            />
          </div>

          <div className="flex gap-px self-start mt-9 text-sm leading-loose">
            <div className="flex-auto text-blue-950">
              By submitting this form I accept Propio Language Services's{" "}
            </div>
            <button className="text-cyan-400">Privacy Policy</button>
          </div>

          <div className="flex flex-col justify-center py-px mt-6 max-w-full bg-white w-[304px]">
            <div className="flex overflow-hidden flex-col px-2 py-2.5 w-full rounded border border-solid shadow-sm bg-stone-50 border-neutral-300">
              <div className="flex gap-5 justify-between w-full">
                <div className="flex gap-2 self-start mt-3 text-sm leading-none text-black">
                  <img
                    loading="lazy"
                    src="https://cdn.builder.io/api/v1/image/assets/TEMP/f37942b87380c0038980ddbc145cbcfac2c0a121df33d71dc07bb63c759f63f5?placeholderIfAbsent=true&apiKey=9c736499c4884251b60cdafcdc215d29"
                    alt="reCAPTCHA checkbox"
                    className="object-contain shrink-0 aspect-[1.27] w-[38px]"
                  />
                  <div className="my-auto">I'm not a robot</div>
                </div>
                <div className="flex flex-col text-xs leading-none text-center whitespace-nowrap text-neutral-600">
                  <img
                    loading="lazy"
                    src="https://cdn.builder.io/api/v1/image/assets/TEMP/27e42b55eb8d6730af955df27e590fd9cb0f2c4189813fe8937bd6dc32ea681d?placeholderIfAbsent=true&apiKey=9c736499c4884251b60cdafcdc215d29"
                    alt="reCAPTCHA logo"
                    className="object-contain self-center w-8 aspect-square"
                  />
                  <div className="mt-1.5">reCAPTCHA</div>
                </div>
              </div>
              <div className="flex gap-1.5 self-end mt-1.5 text-xs text-right">
                <button className="grow text-neutral-600">Privacy</button>
                <div className="flex gap-px self-start">
                  <div className="my-auto text-black"> - </div>
                  <button className="text-neutral-600">Terms</button>
                </div>
              </div>
            </div>
          </div>

          <button type="submit" className="overflow-hidden self-end px-16 py-3.5 mt-6 max-w-full text-sm font-semibold text-center text-cyan-400 whitespace-nowrap border border-cyan-400 border-solid rounded-[200px] w-[230px] max-md:px-5">
            Submit
          </button>
        </div>
      </form>
    </div>
  );
}

export default ContactForm;