import React from "react";
import Image from "next/image";
import Tick from "@/public/svgs/tick.svg"

export default function Features() {
  const features = [
    {
      title: "Highly Qualified Interpreters",
      description:
        "Our rigorously vetted and trained interpreters understand and abide by industry-recognized standards and HIPAA, FERPA, and GLBA requirements.",
    },
    {
      title: "Industry-Leading Technology",
      description:
        "With fast connect times, 24/7/365 availability, constant connectivity monitoring, and customized account options, our technology speaks for itself.",
    },
    {
      title: "Easy Implementation",
      description:
        "Your dedicated Client Success Team will work with you every step of the way to ensure a seamless implementation. We deliver best-in-class client service and ongoing partnerships.",
    },
  ];

  return (
    <div className="py-12 w-full text-white bg-blue-950">
      <div className="max-w-[1245px] mx-auto max-xl:px-6">
        <div className="grid grid-cols-1 md:grid-cols-2 gap-5 justify-between max-w-full w-[1259px]">
          <div className="flex flex-col items-start self-start mt-2">
            <h2 className="text-4xl font-semibold leading-10">
              Where quality and value intersect
            </h2>
            {features.map((feature, index) => (
              <div
                key={index}
                className="flex gap-2 items-start mt-10 first:mt-10"
              >
                <Image
                  loading="lazy"
                  src={Tick}
                  className="object-contain shrink-0 aspect-square"
                  alt={feature.title}
                  width={30}
                  height={30}
                />
                <div className="flex flex-col grow shrink-0 basis-0 w-fit">
                  <h3 className="self-start text-base font-bold leading-loose text-yellow-500">
                    {feature.title}
                  </h3>
                  <p className="mt-2.5 text-sm leading-5">
                    {feature.description}
                  </p>
                </div>
              </div>
            ))}
          </div>
          <img
            loading="lazy"
            src="https://cdn.builder.io/api/v1/image/assets/TEMP/e9c8c897aca30091ca8ae6feb00abb180d7afd3d757a74deaf5243902488a3e6?placeholderIfAbsent=true&apiKey=9c736499c4884251b60cdafcdc215d29"
            className="object-contain w-full aspect-[1.05] max-md:max-w-full"
            alt="Features illustration"
          />
        </div>
      </div>
    </div>
  );
}
