import React from "react";
import Image from "next/image";
import Link from "next/link";
import Logo from "@/public/images/logo.png";

export default function Footer() {
  return (
    <footer className="bg-blue-950 text-white py-16">
      <div className="max-w-[1245px] mx-auto max-xl:px-6">
        <div className="flex max-sm:flex-col flex-wrap justify-between gap-10">
          <Link href="/">
            <div className="justify-start items-start flex gap-3">
              <Image src={Logo} alt="Logo" width={80} height={80} />
            </div>
          </Link>

          <div className="flex max-sm:flex-col justify-between gap-10">
            <div className="min-w-[150px]">
              <h3 className="text-lg font-semibold mb-4">Services</h3>
              <ul className="space-y-2">
                <li className="cursor-pointer hover:underline">Interpreting</li>
                <li className="cursor-pointer hover:underline">
                  Translation and Localization
                </li>
                <li className="cursor-pointer hover:underline">WorkforceOS</li>
                <li className="cursor-pointer hover:underline">Analytics</li>
              </ul>
            </div>

            <div className="min-w-[150px]">
              <h3 className="text-lg font-semibold mb-4">Resources</h3>
              <ul className="space-y-2">
                <li className="cursor-pointer hover:underline">
                  Language Codes
                </li>
                <li className="cursor-pointer hover:underline">
                  Frequently Asked Questions
                </li>
                <li className="cursor-pointer hover:underline">Careers</li>
                <li className="cursor-pointer hover:underline">
                  Interpreter and Translator Jobs
                </li>
                <li className="cursor-pointer hover:underline">Legal</li>
              </ul>
            </div>

            <div className="min-w-[200px]">
              <h3 className="text-lg font-semibold mb-4">Contact Us</h3>
              <ul className="space-y-2">
                <li className="cursor-pointer">Propio Language Services</li>
                <li className="cursor-pointer">10801 Mastin St. #580</li>
                <li className="cursor-pointer">Overland Park, KS 66210</li>
                <li className="cursor-pointer">Local: 913-381-3143</li>
                <li className="cursor-pointer">Fax: 866-231-8176</li>
              </ul>

              <div className="flex gap-4 mt-4 text-cyan-500">
                <a href="#" aria-label="Facebook">
                  <span className="text-xl">f</span>
                </a>
                <a href="#" aria-label="LinkedIn">
                  <span className="text-xl">in</span>
                </a>
              </div>
            </div>
          </div>
        </div>

        <div className="mt-10 text-center text-sm text-gray-400">
          © Propio Language Services 2024. All rights reserved. |{" "}
          <a href="#" className="text-cyan-500">
            Privacy Policy
          </a>
        </div>
      </div>
    </footer>
  );
}
