import React from "react";
import Image from "next/image";
import Tick from "@/public/svgs/tick.svg";

const KeyFeatures = ({ imgSrc, title, description, works }) => {
  return (
    <section className="max-w-[1245px] mx-auto max-xl:px-6">
      <div className="grid gap-10 md:grid-cols-2 py-16 md:py-24">
        <div className="max-md:ml-0">
          <article className="flex flex-col items-start w-full text-blue-950 max-md:mt-10">
            <h1 className="text-4xl font-semibold">{title}</h1>

            <p className="self-stretch mt-6 text-base leading-7 max-md:mt-10 max-md:max-w-full">
              {description}
            </p>

            {works.length > 0 && (
              <ul className="w-full">
                {works.map((work, index) => (
                  <li key={index} className="mt-5 first:mt-7">
                    <div className="flex gap-2">
                      <Image
                        loading="lazy"
                        src={Tick}
                        className="object-contain shrink-0 aspect-square w-[30px]"
                        alt="Feature Icon"
                      />
                      <div className="max-w-96 flex flex-auto gap-1 my-auto">
                        <strong className="text-base font-bold leading-loose">
                          {work.title}
                        </strong>
                      </div>
                    </div>
                    {work.description && (
                      <p className="mt-1.5 ml-10 text-sm leading-none max-md:ml-2.5">
                        {work.description}
                      </p>
                    )}
                  </li>
                ))}
              </ul>
            )}
          </article>
        </div>

        <Image
          loading="lazy"
          src={imgSrc}
          className="w-full max-md:mt-10"
          alt="Phone interpretation features illustration"
        />
      </div>
    </section>
  );
};

KeyFeatures.defaultProps = {
  title: "How it Works",
  description: "",
  works: [],
};

export default KeyFeatures;
