import React from "react";
import Image from "next/image";
import Tick from "@/public/svgs/tick.svg";

const KeyFeatures = ({ imgSrc, title, description, features }) => {
  return (
    <section className="max-w-[1245px] mx-auto max-xl:px-6">
      <div className="grid gap-10 lg:grid-cols-2 py-16 lg:py-24">
        <Image
          loading="lazy"
          src={imgSrc}
          className="object-contain w-full aspect-[1.05] max-md:mt-10 max-md:max-w-full"
          alt="Phone interpretation features illustration"
        />
        <div className="max-md:ml-0">
          <article className="flex flex-col items-start w-full text-blue-950 max-md:mt-10">
            <h1 className="text-4xl font-semibold">{title}</h1>

            <p className="self-stretch mt-6 text-base leading-7 max-md:mt-10 max-md:max-w-full">
              {description}
            </p>

            <ul className="w-full">
              {features.map((feature, index) => (
                <li key={index} className="mt-5 first:mt-7">
                  <div className="flex gap-2">
                    <Image
                      loading="lazy"
                      src={Tick}
                      className=" md:object-contain"
                      alt="Feature Icon"
                    />
                    <div className="flex flex-auto gap-1 my-auto">
                      <strong className="text-base font-bold leading-loose">
                        {feature.title}
                      </strong>
                    </div>
                  </div>
                  <p className="mt-1.5 ml-10 text-sm leading-none">
                    {feature.description}
                  </p>
                </li>
              ))}
            </ul>
          </article>
        </div>
      </div>
    </section>
  );
};

KeyFeatures.defaultProps = {
  title: "Key Features",
  description: "Explore the benefits of our interpretation services.",
  features: [],
};

export default KeyFeatures;
