"use client";

import { useState, useEffect } from "react";
import Image from "next/image";
import Link from "next/link";
import Logo from "@/public/images/logo.png";

export default function Navbar() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [isSticky, setIsSticky] = useState(false);

  const handleMenuToggle = () => {
    setIsMenuOpen(!isMenuOpen);
    document.body.style.overflow = isMenuOpen ? "auto" : "hidden";
  };

  const handleMenuClose = () => {
    setIsMenuOpen(false);
    document.body.style.overflow = "auto";
  };

  useEffect(() => {
    const handleScroll = () => {
      if (window.scrollY > 0) {
        setIsSticky(true);
      } else {
        setIsSticky(false);
      }
    };

    window.addEventListener("scroll", handleScroll);
    return () => window.removeEventListener("scroll", handleScroll);
  }, []);

  return (
    <div
      className={`fixed top-0 w-full z-50 transition-all duration-300 ease-in-out bg-[#082348] ${
        isSticky ? "shadow-md" : ""
      }`}
    >
      <div className="max-w-[1245px] mx-auto flex justify-between items-center py-4 px-4">
        <div className="flex items-center gap-8">
          <Link href="/">
            <p className="cursor-pointer">
              <Image src={Logo} alt="Logo" width={80} height={80} />
            </p>
          </Link>
        </div>

        <div className="flex items-center gap-6 max-md:hidden">
          <nav className="max-md:hidden flex gap-6 text-white text-sm">
            {["Interpretation", "Careers", "About-Us"].map((item, index) => (
              <Link href={`/${item.toLowerCase()}`} key={index}>
                <p className="hover:underline">{item}</p>
              </Link>
            ))}
          </nav>
          <Link href="/contact-us">
            <button className="px-10 py-2 font-semibold text-sm rounded-full border-2 text-yellow-500 border-yellow-500 border-opacity-80 hover:bg-yellow-500 hover:text-blue-950 transition-colors">
              Contact Us
            </button>
          </Link>
        </div>

        <div className="md:hidden">
          <button
            className="text-white focus:outline-none"
            onClick={handleMenuToggle}
            aria-label="Toggle Menu"
          >
            {isMenuOpen ? (
              <span className="text-3xl">&times;</span>
            ) : (
              <span className="text-3xl">&#9776;</span>
            )}
          </button>
        </div>
      </div>

      {isMenuOpen && (
        <div className="fixed inset-0 bg-[#082348] text-white flex flex-col">
          <div className="flex justify-between items-center p-4">
            <Link href="/">
              <div
                className="flex items-center gap-2 cursor-pointer"
                onClick={handleMenuClose}
              >
                <Image src={Logo} alt="Logo" width={60} height={60} />
              </div>
            </Link>
            <button
              className="text-white text-2xl focus:outline-none border px-2.5 pt-[2px] rounded-full"
              onClick={handleMenuClose}
              aria-label="Close Menu"
            >
              &times;
            </button>
          </div>

          <div className="px-4">
            <hr />
          </div>

          <nav className="pl-4 mt-8 flex-grow flex flex-col gap-6 text-xl">
            {["Interpretation", "Careers", "About-Us"].map((item, index) => (
              <Link href={`/${item.toLowerCase()}`} key={index}>
                <p className="hover:underline" onClick={handleMenuClose}>
                  {item}
                </p>
              </Link>
            ))}
          </nav>

          <Link href="/contact-us" className="p-4">
            <button
              className="w-full px-8 py-3 font-semibold text-lg rounded-full border-2 text-yellow-600 border-yellow-600 hover:bg-yellow-600 hover:text-blue-950 transition-colors"
              onClick={handleMenuClose}
            >
              Contact Us
            </button>
          </Link>
        </div>
      )}
    </div>
  );
}
